@@ -27,9 +27,11 @@ from .errors import EncodeError
 from .errors import DecodeError
 from .errors import CompileError
 from .errors import ConstraintsError
-from . import c_source
+from . source import c
+from . source import rust
 from .version import __version__
 
+
 __author__ = 'Erik Moqvist'
 
 
@@ -147,13 +149,13 @@ def _handle_command_compile(line):
     parser.add_argument('-i', '--input-codec',
                         choices=('ber', 'der', 'jer', 'oer', 'per', 'uper', 'xer'),
                         default='ber',
-                        help='Input codec (default: ber).')
+                        help='Input codec (default: %(default)s).')
     parser.add_argument('-o', '--output-codec',
                         choices=(
                             'ber', 'der', 'jer', 'oer', 'per', 'uper', 'xer', 'gser'
                         ),
                         default='gser',
-                        help='Output codec (default: gser).')
+                        help='Output codec (default: %(default)s).')
     parser.add_argument('-c', '--cache-dir',
                         help='Cache directory.')
     parser.add_argument('specification',
@@ -268,13 +270,18 @@ def _do_generate_c_source(args):
 
     filename_h = name + '.h'
     filename_c = name + '.c'
+    fuzzer_filename_c = name + '_fuzzer.c'
+    fuzzer_filename_mk = name + '_fuzzer.mk'
 
     compiled = compile_files(args.specification,
                              args.codec)
-    header, source = c_source.generate(compiled,
-                                       args.codec,
-                                       name,
-                                       filename_h)
+    header, source, fuzzer_source, fuzzer_makefile = c.generate(
+        compiled,
+        args.codec,
+        name,
+        filename_h,
+        filename_c,
+        fuzzer_filename_c)
 
     with open(filename_h, 'w') as fout:
         fout.write(header)
@@ -282,7 +289,38 @@ def _do_generate_c_source(args):
     with open(filename_c, 'w') as fout:
         fout.write(source)
 
-    print('Successfully generated {} and {}.'.format(filename_h, filename_c))
+    print('Successfully generated {} and {}.'.format(filename_h,
+                                                     filename_c))
+
+    if args.generate_fuzzer:
+        with open(fuzzer_filename_c, 'w') as fout:
+            fout.write(fuzzer_source)
+
+        with open(fuzzer_filename_mk, 'w') as fout:
+            fout.write(fuzzer_makefile)
+
+        print('Successfully generated {} and {}.'.format(fuzzer_filename_c,
+                                                         fuzzer_filename_mk))
+        print()
+        print(
+            'Run "make -f {}" to build and run the fuzzer. Requires a'.format(
+                fuzzer_filename_mk))
+        print('recent version of clang.')
+
+
+def _do_generate_rust_source(args):
+    name = os.path.basename(args.specification[0])
+    name = os.path.splitext(name)[0]
+    filename_rs = name + '.rs'
+
+    compiled = compile_files(args.specification,
+                             args.codec)
+    source = rust.generate(compiled, args.codec)
+
+    with open(filename_rs, 'w') as fout:
+        fout.write(source)
+
+    print('Successfully generated {}.'.format(filename_rs))
 
 
 def _main():
@@ -295,7 +333,7 @@ def _main():
                         type=int,
                         default=1,
                         help=('Control the verbosity; disable(0), warning(1) '
-                              'and debug(2). (default: 1).'))
+                              'and debug(2) (default: %(default)s).'))
     parser.add_argument('--version',
                         action='version',
                         version=__version__,
@@ -314,12 +352,12 @@ def _main():
         '-i', '--input-codec',
         choices=('ber', 'der', 'jer', 'oer', 'per', 'uper', 'xer'),
         default='ber',
-        help='Input format (default: ber).')
+        help='Input format (default: %(default)s).')
     subparser.add_argument(
         '-o', '--output-codec',
         choices=('ber', 'der', 'jer', 'oer', 'per', 'uper', 'xer', 'gser'),
         default='gser',
-        help='Output format (default: gser).')
+        help='Output format (default: %(default)s).')
     subparser.add_argument('-c', '--cache-dir',
                            help='Cache directory.')
     subparser.add_argument(
@@ -356,15 +394,33 @@ def _main():
         '-c', '--codec',
         choices=('oer', 'uper'),
         default='oer',
-        help='Codec to generate code for (default: oer).')
+        help='Codec to generate code for (default: %(default)s).')
     subparser.add_argument(
         '-n', '--namespace',
         help='Namespace of defines, structs, functions, files, etc.')
+    subparser.add_argument(
+        '-f', '--generate-fuzzer',
+        action='store_true',
+        help='Also generate fuzzer source code.')
     subparser.add_argument('specification',
                            nargs='+',
                            help='ASN.1 specification as one or more .asn files.')
     subparser.set_defaults(func=_do_generate_c_source)
 
+    # The 'generate_rust_source' subparser.
+    subparser = subparsers.add_parser(
+        'generate_rust_source',
+        description='Generate Rust source code from given ASN.1 specification.')
+    subparser.add_argument(
+        '-c', '--codec',
+        choices=('uper', ),
+        default='uper',
+        help='Codec to generate code for (default: %(default)s).')
+    subparser.add_argument('specification',
+                           nargs='+',
+                           help='ASN.1 specification as one or more .asn files.')
+    subparser.set_defaults(func=_do_generate_rust_source)
+
     args = parser.parse_args()
 
     levels = [logging.CRITICAL, logging.WARNING, logging.DEBUG]
