@@ -369,18 +369,23 @@ def convert_sequence_type(_s, _l, tokens):
 
 
 def convert_sequence_of_type(_s, _l, tokens):
+    is_named_element = len(tokens) == 6
+
     converted_type = {
         'type': 'SEQUENCE OF',
-        'element': convert_type(tokens[4], []),
+        'element': convert_type(tokens[5 if is_named_element else 4], []),
     }
 
+    if (is_named_element):
+        converted_type['element_name'] = tokens[3]
+
     if len(tokens[1]) > 0:
         converted_type['size'] = tokens[1][0][0]['size']
 
         if len(tokens[1]) > 1 and tokens[1][1] == '...':
             converted_type['size'].append(None)
 
-    tag = convert_tag(tokens[3])
+    tag = convert_tag(tokens[4 if is_named_element else 3])
 
     if tag:
         converted_type['element']['tag'] = tag
@@ -396,18 +401,23 @@ def convert_set_type(_s, _l, tokens):
 
 
 def convert_set_of_type(_s, _l, tokens):
+    is_named_element = len(tokens) == 6
+
     converted_type = {
         'type': 'SET OF',
-        'element': convert_type(tokens[4], [])
+        'element': convert_type(tokens[5 if is_named_element else 4], [])
     }
 
+    if (is_named_element):
+        converted_type['element_name'] = tokens[3]
+
     if len(tokens[1]) > 0:
         converted_type['size'] = tokens[1][0][0]['size']
 
         if len(tokens[1]) > 1 and tokens[1][1] == '...':
             converted_type['size'].append(None)
 
-    tag = convert_tag(tokens[3])
+    tag = convert_tag(tokens[4 if is_named_element else 3])
 
     if tag:
         converted_type['element']['tag'] = tag
@@ -1244,8 +1254,9 @@ def create_grammar():
                              + right_brace)
     single_type_constraint = constraint
     multiple_type_constraints = (full_specification | partial_specification)
-    inner_type_constraints = ((WITH_COMPONENT - single_type_constraint)
-                              | (WITH_COMPONENTS - multiple_type_constraints))
+    with_component = WITH_COMPONENT - single_type_constraint
+    with_components = WITH_COMPONENTS - multiple_type_constraints
+    inner_type_constraints = with_component | with_components
     permitted_alphabet = (FROM - constraint)
     type_constraint = type_
     size_constraint <<= (SIZE - Group(constraint))
@@ -1421,7 +1432,7 @@ def create_grammar():
     set_of_type = (SET
                    + Group(Optional(Group(size_constraint) | constraint))
                    + OF
-                   + Optional(Suppress(identifier))
+                   + Optional(identifier)
                    - tag
                    - type_)
     set_of_type.setName('SET OF')
@@ -1441,7 +1452,7 @@ def create_grammar():
     sequence_of_type = (SEQUENCE
                         + Group(Optional(Group(size_constraint) | constraint))
                         + OF
-                        + Optional(Suppress(identifier))
+                        + Optional(identifier)
                         - tag
                         - type_)
     sequence_of_type.setName('SEQUENCE OF')
@@ -1715,7 +1726,8 @@ def create_grammar():
     bstring.setParseAction(convert_bstring)
     hstring.setParseAction(convert_hstring)
     value_range.setParseAction(convert_value_range)
-    inner_type_constraints.setParseAction(convert_inner_type_constraints)
+    with_component.setParseAction(convert_inner_type_constraints)
+    with_components.setParseAction(convert_inner_type_constraints)
     size_constraint.setParseAction(convert_size_constraint)
     permitted_alphabet.setParseAction(convert_permitted_alphabet)
     constraint.setParseAction(convert_constraint)
