@@ -90,6 +90,9 @@ class _Generator(Generator):
         elif isinstance(type_, uper.OctetString):
             lines = self.format_octet_string(checker)[1:-1]
             lines = dedent_lines(lines)
+        elif isinstance(type_, uper.BitString):
+            lines = self.format_bit_string(type_, checker)
+            lines[0] += ' value;'
         elif isinstance(type_, uper.Null):
             lines = []
         else:
@@ -113,6 +116,8 @@ class _Generator(Generator):
             return self.format_choice_inner(type_, checker)
         elif isinstance(type_, uper.OctetString):
             return self.format_octet_string_inner(type_, checker)
+        elif isinstance(type_, uper.BitString):
+            return self.format_bit_string_inner(type_)
         elif isinstance(type_, uper.Enumerated):
             return self.format_enumerated_inner(type_)
         elif isinstance(type_, uper.Null):
@@ -194,6 +199,7 @@ class _Generator(Generator):
         member_name_to_is_present = {}
 
         if type_.additions is not None:
+
             if len(type_.additions) > 0:
                 if_line = 'if({}) {{'.format(self.get_addition_present_condition(type_))
                 encode_lines.extend(textwrap.wrap(if_line, 120,
@@ -203,6 +209,7 @@ class _Generator(Generator):
                 encode_lines.append('}')
 
             encode_lines.append('encoder_append_bool(encoder_p, false);')
+
             if len(type_.additions) > 0:
                 unique_extension_present = \
                     self.add_unique_decode_variable('bool {};', 'extension_is_present')
@@ -212,9 +219,10 @@ class _Generator(Generator):
                 decode_lines.append('decoder_read_bool(decoder_p);')
 
         for member in type_.root_members:
+
             if member.optional:
                 name = '{}is_{}_present'.format(self.location_inner('', '.'),
-                                                member.name)
+                                                canonical(member.name))
                 encode_lines.append(
                     'encoder_append_bool(encoder_p, src_p->{});'.format(
                         name))
@@ -225,12 +233,28 @@ class _Generator(Generator):
                 unique_is_present = self.add_unique_decode_variable('bool {};',
                                                                     'is_present')
                 member_name_to_is_present[member.name] = unique_is_present
-                encode_lines.append(
-                    'encoder_append_bool(encoder_p, src_p->{}{}{} != {});'.format(
-                        self.location_inner('', '.'),
-                        member.name,
-                        '.value' if self.is_complex_user_type(member) else '',
-                        self.format_default(member)))
+
+                if self.is_buffer_type(member):
+                    default_variable = canonical(member.name) + '_default'
+
+                    encode_lines += [
+                        'encoder_append_bool(encoder_p, (memcmp(src_p->{}{}.buf, {}, sizeof({})) != 0) ||'.format(
+                            self.location_inner('', '.'),
+                            canonical(member.name),
+                            default_variable,
+                            default_variable),
+                        '                               (src_p->{}{}.length != sizeof({})));'.format(
+                            self.location_inner('', '.'),
+                            canonical(member.name),
+                            default_variable)
+                    ]
+                else:
+                    encode_lines.append(
+                        'encoder_append_bool(encoder_p, src_p->{}{}{} != {});'.format(
+                            self.location_inner('', '.'),
+                            canonical(member.name),
+                            '.value' if self.is_complex_user_type(member) else '',
+                            self.format_default(member)))
                 decode_lines.append(
                     '{} = decoder_read_bool(decoder_p);'.format(
                         unique_is_present))
@@ -338,9 +362,9 @@ class _Generator(Generator):
             member_checker = self.get_member_checker(checker,
                                                      member.name)
 
-            with self.asn1_members_backtrace_push(member.name):
+            with self.asn1_members_backtrace_push(canonical(member.name)):
                 with self.c_members_backtrace_push('value'):
-                    with self.c_members_backtrace_push(member.name):
+                    with self.c_members_backtrace_push(canonical(member.name)):
                         choice_encode_lines, choice_decode_lines = self.format_type_inner(
                             member,
                             member_checker)
@@ -355,7 +379,7 @@ class _Generator(Generator):
                 'break;'
             ]
             encode_lines += [
-                'case {}_choice_{}_e:'.format(self.location, member.name)
+                'case {}_choice_{}_e:'.format(self.location, canonical(member.name))
             ] + indent_lines(choice_encode_lines) + [
                 ''
             ]
@@ -363,7 +387,7 @@ class _Generator(Generator):
             choice_decode_lines = [
                 'dst_p->{} = {}_choice_{}_e;'.format(choice,
                                                      self.location,
-                                                     member.name)
+                                                     canonical(member.name))
             ] + choice_decode_lines + [
                 'break;'
             ]
@@ -580,6 +604,9 @@ class _Generator(Generator):
         return is_user_type(type_) and \
             not isinstance(type_, (uper.Integer, uper.Boolean, uper.Real, uper.Null))
 
+    def is_buffer_type(self, type_):
+        return isinstance(type_, uper.OctetString)
+
     def generate_helpers(self, definitions):
         helpers = []
 
