@@ -7,8 +7,8 @@ EXPECTED = {'IEEE1609dot2': {'extensibility-implied': False,
                                                         'GroupLinkageValue',
                                                         'HashAlgorithm',
                                                         'HashedId3',
-                                                        'HashedId8',
                                                         'HashedId32',
+                                                        'HashedId8',
                                                         'Hostname',
                                                         'IValue',
                                                         'LinkageValue',
@@ -26,10 +26,10 @@ EXPECTED = {'IEEE1609dot2': {'extensibility-implied': False,
                                                         'SymmetricEncryptionKey',
                                                         'ThreeDLocation',
                                                         'Time64',
-                                                        'Uint3',
-                                                        'Uint8',
                                                         'Uint16',
+                                                        'Uint3',
                                                         'Uint32',
+                                                        'Uint8',
                                                         'ValidityPeriod']},
                   'object-classes': {},
                   'object-sets': {},
@@ -647,7 +647,7 @@ EXPECTED = {'IEEE1609dot2': {'extensibility-implied': False,
                            'values': {}},
  'IEEE1609dot2Crl': {'extensibility-implied': False,
                      'imports': {'IEEE1609dot2': ['Ieee1609Dot2Data'],
-                                 'IEEE1609dot2BaseTypes': ['Psid', 'Opaque'],
+                                 'IEEE1609dot2BaseTypes': ['Opaque', 'Psid'],
                                  'IEEE1609dot2CrlBaseTypes': ['CrlContents']},
                      'object-classes': {},
                      'object-sets': {},
@@ -689,8 +689,8 @@ EXPECTED = {'IEEE1609dot2': {'extensibility-implied': False,
  'IEEE1609dot2CrlBaseTypes': {'extensibility-implied': False,
                               'imports': {'IEEE1609dot2BaseTypes': ['CrlSeries',
                                                                     'GeographicRegion',
-                                                                    'HashedId8',
                                                                     'HashedId10',
+                                                                    'HashedId8',
                                                                     'IValue',
                                                                     'LaId',
                                                                     'LinkageSeed',
@@ -698,10 +698,10 @@ EXPECTED = {'IEEE1609dot2': {'extensibility-implied': False,
                                                                     'Psid',
                                                                     'Signature',
                                                                     'Time32',
-                                                                    'Uint3',
-                                                                    'Uint8',
                                                                     'Uint16',
+                                                                    'Uint3',
                                                                     'Uint32',
+                                                                    'Uint8',
                                                                     'ValidityPeriod']},
                               'object-classes': {},
                               'object-sets': {},
