@@ -1,8 +1,8 @@
 EXPECTED = {'RFC1157-SNMP': {'extensibility-implied': False,
-                  'imports': {'RFC1155-SMI': ['ObjectName',
-                                              'ObjectSyntax',
+                  'imports': {'RFC1155-SMI': ['IpAddress',
                                               'NetworkAddress',
-                                              'IpAddress',
+                                              'ObjectName',
+                                              'ObjectSyntax',
                                               'TimeTicks']},
                   'object-classes': {},
                   'object-sets': {},
