@@ -1,16 +1,16 @@
 EXPECTED = {'PKIXCMP': {'extensibility-implied': False,
              'imports': {'PKCS-10': ['CertificationRequest'],
-                         'PKIX1Explicit88': ['Certificate',
+                         'PKIX1Explicit88': ['AlgorithmIdentifier',
+                                             'Certificate',
                                              'CertificateList',
                                              'Extensions',
-                                             'AlgorithmIdentifier',
                                              'UTF8String'],
                          'PKIX1Implicit88': ['GeneralName', 'KeyIdentifier'],
-                         'PKIXCRMF-2005': ['CertTemplate',
-                                           'PKIPublicationInfo',
+                         'PKIXCRMF-2005': ['CertId',
+                                           'CertReqMessages',
+                                           'CertTemplate',
                                            'EncryptedValue',
-                                           'CertId',
-                                           'CertReqMessages']},
+                                           'PKIPublicationInfo']},
              'object-classes': {},
              'object-sets': {},
              'tags': 'EXPLICIT',
