@@ -13,6 +13,14 @@ EXPECTED = {'A': {'extensibility-implied': False,
        'types': {'AnotherType': {'type': 'Type'}},
        'values': {'anotherValue': {'type': 'AnotherType', 'value': 'value'}}},
  'C': {'extensibility-implied': False,
+       'imports': {'B': ['Type', 'anotherValue']},
+       'object-classes': {},
+       'object-sets': {},
+       'tags': 'AUTOMATIC',
+       'types': {'AndAnotherType': {'type': 'Type'}},
+       'values': {'andAnotherValue': {'type': 'AndAnotherType',
+                                      'value': 'anotherValue'}}},
+ 'D': {'extensibility-implied': False,
        'imports': {'B': ['Type', 'anotherValue']},
        'object-classes': {},
        'object-sets': {},
