@@ -108,7 +108,7 @@ class Asn1ToolsCodecsConsistencyTest(Asn1ToolsBaseTest):
                                      decoded,
                                      encoded_message)
 
-    def decode_codecs(self, type_spec, decoded, encoded):
+    def decode_codecs(self, type_spec, decoded, encoded, numeric_enums=False):
         spec = (
             "Foo DEFINITIONS AUTOMATIC TAGS ::= "
             "BEGIN "
@@ -117,7 +117,7 @@ class Asn1ToolsCodecsConsistencyTest(Asn1ToolsBaseTest):
         )
 
         for codec, encoded_message in zip(CODECS, encoded):
-            foo = asn1tools.compile_string(spec, codec)
+            foo = asn1tools.compile_string(spec, codec, numeric_enums=numeric_enums)
             decoded_message = foo.decode('A',
                                          encoded_message,
                                          check_constraints=True)
@@ -175,6 +175,21 @@ class Asn1ToolsCodecsConsistencyTest(Asn1ToolsBaseTest):
                                       [0, 5],
                                       numeric_enums=True)
 
+        # Enum with default
+        decoded = {"e": 5}
+
+        encoded_messages = [
+            b'0\x00',
+            b'0\x00',
+            b'{}',
+            b'\x00',
+            b'\x00',
+            b'\x00',
+            b'<A/>'
+        ]
+
+        self.decode_codecs('SEQUENCE { e ENUMERATED { a(0), b(5) } DEFAULT b }', decoded, encoded_messages, numeric_enums=True)
+
     def test_enumerated_versions(self):
         # Unknown enumeration value 'c' decoded as None.
         decoded_v1 = None
@@ -307,9 +322,8 @@ class Asn1ToolsCodecsConsistencyTest(Asn1ToolsBaseTest):
 
             with self.assertRaises(asn1tools.EncodeError) as cm:
                 foo.encode('A', {'a': {'b': ('c', {})}})
-
             self.assertEqual(str(cm.exception),
-                             "a: b: c: Sequence member 'd' not found in {}.")
+                             "A.a.b.c: Sequence member 'd' not found in {}.")
 
     def test_recursive(self):
         spec = (
@@ -623,37 +637,37 @@ class Asn1ToolsCodecsConsistencyTest(Asn1ToolsBaseTest):
             (
                 'Constants',
                 -2,
-                'Expected an integer between -1 and 2, but got -2.'
+                'Constants: Expected an integer between -1 and 2, but got -2.'
             ),
             (
                 'Constants',
                 3,
-                'Expected an integer between -1 and 2, but got 3.'
+                'Constants: Expected an integer between -1 and 2, but got 3.'
             ),
             (
                 'A',
                 -2,
-                'Expected an integer between -1 and 1, but got -2.'
+                'A: Expected an integer between -1 and 1, but got -2.'
             ),
             (
                 'A',
                 2,
-                'Expected an integer between -1 and 1, but got 2.'
+                'A: Expected an integer between -1 and 1, but got 2.'
             ),
             (
                 'B',
                 1,
-                'Expected an integer between 2 and 2, but got 1.'
+                'B: Expected an integer between 2 and 2, but got 1.'
             ),
             (
                 'C',
                 -1,
-                'Expected an integer between 0 and 1, but got -1.'
+                'C: Expected an integer between 0 and 1, but got -1.'
             ),
             (
                 'C',
                 2,
-                'Expected an integer between 0 and 1, but got 2.'
+                'C: Expected an integer between 0 and 1, but got 2.'
             )
         ]
 
