@@ -6,6 +6,7 @@ import asn1tools
 
 sys.path.append('tests/files')
 sys.path.append('tests/files/3gpp')
+sys.path.append('tests/files/cen')
 sys.path.append('tests/files/etsi')
 sys.path.append('tests/files/ieee')
 sys.path.append('tests/files/ietf')
@@ -138,6 +139,12 @@ class Asn1ToolsParseTest(unittest.TestCase):
     def test_parse_etsi_its_container_1_2_1(self):
         self.parse_and_verify('its_container_1_2_1', 'etsi')
 
+    def test_parse_etsi_mapem_2_1_1(self):
+        self.parse_and_verify('mapem_2_1_1', 'etsi')
+
+    def test_parse_cen_dsrc(self):
+        self.parse_and_verify('dsrc', 'cen')
+
     def test_parse_ieee_1609_2(self):
         self.parse_and_verify('ieee1609_2', 'ieee')
 
@@ -304,8 +311,8 @@ class Asn1ToolsParseTest(unittest.TestCase):
 
         self.assertEqual(
             str(cm.exception),
-            "Invalid ASN.1 syntax at line 1, column 45: 'A DEFINITIONS ::= BEGIN "
-            " A ::= SEQUENCE { a >!<} END': Expected Type.")
+            "Invalid ASN.1 syntax at line 1, column 43: 'A DEFINITIONS ::= BEGIN "
+            " A ::= SEQUENCE { >!<a } END': Expected Type.")
 
     def test_parse_error_sequence_missing_member_name(self):
         with self.assertRaises(asn1tools.ParseError) as cm:
@@ -316,7 +323,7 @@ class Asn1ToolsParseTest(unittest.TestCase):
         self.assertEqual(
             str(cm.exception),
             "Invalid ASN.1 syntax at line 1, column 43: 'A DEFINITIONS ::= "
-            "BEGIN  A ::= SEQUENCE { >!<A } END': Expected \"}\".")
+            "BEGIN  A ::= SEQUENCE { >!<A } END': Expected Type.")
 
     def test_parse_error_definitive_identifier(self):
         with self.assertRaises(asn1tools.ParseError) as cm:
@@ -326,8 +333,8 @@ class Asn1ToolsParseTest(unittest.TestCase):
         self.assertEqual(
             str(cm.exception),
             "Invalid ASN.1 syntax at line 1, column 4: 'A {>!<} DEFINITIONS "
-            "::= BEGIN END': Expected {{identifier Suppress:(\"(\") - "
-            "definitiveNumberForm - Suppress:(\")\")} | identifier | "
+            "::= BEGIN END': Expected {{identifier Suppress:('(') - "
+            "definitiveNumberForm - Suppress:(')')} | identifier | "
             "definitiveNumberForm}.")
 
     def test_parse_error_missing_union_member_beginning(self):
@@ -338,8 +345,8 @@ class Asn1ToolsParseTest(unittest.TestCase):
 
         self.assertEqual(
             str(cm.exception),
-            "Invalid ASN.1 syntax at line 1, column 40: 'A DEFINITIONS ::= BEGIN "
-            "B ::= INTEGER (>!<| SIZE (1))END': Expected one or more constraints.")
+            "Invalid ASN.1 syntax at line 1, column 39: 'A DEFINITIONS ::= BEGIN "
+            "B ::= INTEGER >!<(| SIZE (1))END': Expected END.")
 
     def test_parse_error_missing_union_member_middle(self):
         with self.assertRaises(asn1tools.ParseError) as cm:
@@ -349,8 +356,8 @@ class Asn1ToolsParseTest(unittest.TestCase):
 
         self.assertEqual(
             str(cm.exception),
-            "Invalid ASN.1 syntax at line 1, column 49: \'A DEFINITIONS "
-            "::= BEGIN B ::= INTEGER (SIZE (1) >!<| | (0))END\': Expected \")\".")
+            "Invalid ASN.1 syntax at line 1, column 39: \'A DEFINITIONS "
+            "::= BEGIN B ::= INTEGER >!<(SIZE (1) | | (0))END\': Expected END.")
 
     def test_parse_error_missing_union_member_end(self):
         with self.assertRaises(asn1tools.ParseError) as cm:
@@ -360,8 +367,8 @@ class Asn1ToolsParseTest(unittest.TestCase):
 
         self.assertEqual(
             str(cm.exception),
-            "Invalid ASN.1 syntax at line 1, column 49: \'A DEFINITIONS "
-            "::= BEGIN B ::= INTEGER (SIZE (1) >!<|)END\': Expected \")\".")
+            "Invalid ASN.1 syntax at line 1, column 39: \'A DEFINITIONS "
+            "::= BEGIN B ::= INTEGER >!<(SIZE (1) |)END\': Expected END.")
 
     def test_parse_error_size_constraint_missing_parentheses(self):
         with self.assertRaises(asn1tools.ParseError) as cm:
@@ -372,7 +379,7 @@ class Asn1ToolsParseTest(unittest.TestCase):
         self.assertEqual(
             str(cm.exception),
             "Invalid ASN.1 syntax at line 1, column 45: \'A DEFINITIONS ::= "
-            "BEGIN B ::= INTEGER (SIZE >!<1)END\': Expected \"(\".")
+            "BEGIN B ::= INTEGER (SIZE >!<1)END\': Expected '('.")
 
     def test_parse_error_size_constraint_missing_size(self):
         with self.assertRaises(asn1tools.ParseError) as cm:
@@ -435,7 +442,7 @@ class Asn1ToolsParseTest(unittest.TestCase):
             str(cm.exception),
             "Invalid ASN.1 syntax at line 1, column 63: \'A DEFINITIONS ::= "
             "BEGIN Foo ::= SEQUENCE { a BOOLEAN, ..., ...>!<, [[ c BOOLEAN ]] "
-            "} END\': Expected \"}\".")
+            "} END\': Expected Type.")
 
     def test_parse_error_too_many_extension_markers(self):
         with self.assertRaises(asn1tools.ParseError) as cm:
@@ -459,7 +466,7 @@ class Asn1ToolsParseTest(unittest.TestCase):
             str(cm.exception),
             "Invalid ASN.1 syntax at line 1, column 108: \'A DEFINITIONS ::= "
             "BEGIN Foo ::= SEQUENCE { a BOOLEAN, ..., [[ b BOOLEAN ]], [[ c "
-            "BOOLEAN ]], ..., d BOOLEAN>!<, ... } END\': Expected \"}\".")
+            "BOOLEAN ]], ..., d BOOLEAN>!<, ... } END\': Expected Type.")
 
     def test_parse_error_missing_single_line_comment_end(self):
         with self.assertRaises(asn1tools.ParseError) as cm:
